import * as core from 'aws-cdk-lib';
import { aws_vpclattice, aws_ec2 as ec2, aws_lambda, aws_elasticloadbalancingv2 as elbv2 } from 'aws-cdk-lib';
import { Protocol, TargetGroup, FixedResponse } from './index';
/**
 * IpAddressType
 */
export declare enum IpAddressType {
    /**
     * ipv4
     */
    IPV4 = "IPV4",
    /**
     * Ipv6
     */
    IPV6 = "IPV6"
}
/**
 * ProtocolVersion
 */
export declare enum ProtocolVersion {
    /**
     * Http1
     */
    HTTP1 = "HTTP1",
    /**
     * Http2
     */
    HTTP2 = "HTTP2",
    /**
     * GRPC
     */
    GRPC = "GRPC"
}
/**
 * Types of Targets that are usable with vpclattice
 */
export declare enum TargetType {
    /**
     * Lambda Target
     */
    LAMBDA = "LAMBDA",
    /**
     * IP Address Target
     */
    IP = "IP",
    /**
     * EC2 Instance Targets
     */
    INSTANCE = "INSTANCE",
    /**
     * Application Load Balancer Target
     */
    ALB = "ALB"
}
/**
 * TargetConfiguration
 */
export interface TargetConfig {
    /**
     * VPC where the target(s) are located
     */
    readonly vpc: ec2.IVpc;
    /**
     * HealthCheckParameters - Can supply for IpAddress and ALB targets only.
     * @default No HealthCheck
     */
    readonly healthcheck?: HealthCheck | undefined;
    /**
     * IpAddressType
     * @default IPv4
     */
    readonly ipAddressType?: IpAddressType;
    /**
     * Protocol
     * @default HTTPS
     */
    readonly protocol?: Protocol | undefined;
    /**
     * Port
     * @default Defaults to port 80 for HTTP, or 443 for HTTPS and GRPC
     */
    readonly port?: number | undefined;
    /**
     * ProtocolVersion
     * @default HTTP1
     */
    readonly protocolVersion?: ProtocolVersion;
}
/**
 * Targets for target Groups
 */
export declare abstract class Target {
    /**
     * Lambda Target - Note: Lambda Targets do not have a configuration
     * @param lambda
     */
    static lambda(lambda: aws_lambda.Function[]): Target;
    /**
     * IpAddress as Targets
     * @param ipAddress
     * @param targetConfig
     */
    static ipAddress(ipAddress: string[], targetConfig: TargetConfig): Target;
    /**
     * EC2 Instances as Targets
     * @param ec2instance
     * @param targetConfig
     */
    static ec2instance(ec2instance: ec2.Instance[], targetConfig: TargetConfig): Target;
    /**
     * Application Load Balancer as Targets
     * @param alb
     * @param targetConfig
     */
    static applicationLoadBalancer(alb: elbv2.ApplicationLoadBalancer[], targetConfig: TargetConfig): Target;
    /**
     * The type of target
     */
    abstract readonly type: TargetType;
    /**
     * References to the targets, ids or Arns
     */
    abstract readonly targets: aws_vpclattice.CfnTargetGroup.TargetProperty[];
    /**
     * Configuration for the TargetGroup, if it is not a lambda
     */
    abstract readonly config?: aws_vpclattice.CfnTargetGroup.TargetGroupConfigProperty | undefined;
    constructor();
}
/**
 * A weighted target group adds a weighting to a target group.
 * when more than one WeightedTargetGroup is provided as the action
 * for a listener, the weights are used to determine the relative proportion
 * of traffic that is sent to the target
 */
export interface WeightedTargetGroup {
    /**
     * A target Group
     */
    readonly targetGroup: TargetGroup;
    /**
    * A weight for the target group.
    * @default 100
    */
    readonly weight?: number | undefined;
}
/**
 * A Configuration of the TargetGroup Health Check.
 */
export interface TargetGroupHealthCheckProps {
    /**
     * Enable this Health Check
     * @default true
     */
    readonly enabled?: boolean | undefined;
    /**
     * Health Check Interval
     * @default 30 seconds
     */
    readonly healthCheckInterval?: core.Duration | undefined;
    /**
     * TimeOut Period
     * @default 5 seconds
     */
    readonly healthCheckTimeout?: core.Duration | undefined;
    /**
     * Number of Healthy Responses before Target is considered healthy
     * @default 2
     */
    readonly healthyThresholdCount?: number | undefined;
    /**
     * Check based on Response from target
     * @default 200 OK
     */
    readonly matcher?: FixedResponse | undefined;
    /**
     * Path to use for Health Check
     * @default '/'
     */
    readonly path?: string | undefined;
    /**
     * Port to use for Health Check
     * @default 443
     */
    readonly port?: number | undefined;
    /**
     * Protocol to use for Health Check
     * @default HTTPS
     */
    readonly protocol?: Protocol | undefined;
    /**
     * Protocol to use for Health Check
     * @default HTTP2
     */
    readonly protocolVersion?: ProtocolVersion | undefined;
    /**
     * Number of unhealty events before Target is considered unhealthy
     * @default 1
     */
    readonly unhealthyThresholdCount?: number | undefined;
}
/**
 * Create a Health Check for a target
 */
export declare abstract class HealthCheck {
    /**
     * A Health Check configuration object for a target
     * @param props
     * @returns HealthCheck
     */
    static check(props: TargetGroupHealthCheckProps): HealthCheck;
    /**
     * health check is enabled.
     */
    abstract readonly enabled: boolean;
    /**
     * healthCheck Interval
     */
    abstract readonly healthCheckInterval: core.Duration;
    /**
     * HealthCheck Timeout
     */
    abstract readonly healthCheckTimeout: core.Duration;
    /**
     * Target Match reponse
     */
    abstract readonly matcher: aws_vpclattice.CfnTargetGroup.MatcherProperty | undefined;
    /**
     * Path to check
     */
    abstract readonly path: string;
    /**
     * Port to check
     */
    abstract readonly port: number;
    /** Protocol
     *
     */
    abstract readonly protocol: string;
    /**
     * HTTP Protocol Version
     */
    abstract readonly protocolVersion: string;
    /**
     * Unhealthy Threshold Count
     */
    abstract readonly unhealthyThresholdCount: number;
    /**
     * Healthy Threshold Count
     */
    abstract readonly healthyThresholdCount: number;
    protected constructor();
}
